@@ -1,18 +1,22 @@
 from typing import Any, Dict
 from requests import Response
 from django.conf import settings
-from django.utils.translation import gettext_lazy as _
 from vanoma_api_utils.http import client
 from djangorestframework_camel_case.util import camelize  # type: ignore
 
 
+class CommunicationApiException(Exception):
+    pass
+
+
 def send_sms(data: Dict[str, Any]) -> Response:
     response = client.post(
         f"{settings.VANOMA_COMMUNICATION_API_URL}/sms", data=camelize(data)
     )
 
     if not response.ok:
-        raise Exception(_(f"Unable to send SMS. Please contact customer support."))
+        json = response.json()
+        raise CommunicationApiException(json["errorMessage"])
 
     return response
 
@@ -23,9 +27,8 @@ def send_push(data: Dict[str, Any]) -> Response:
     )
 
     if not response.ok:
-        raise Exception(
-            _(f"Unable to send push notification. Please contact customer support.")
-        )
+        json = response.json()
+        raise CommunicationApiException(json["errorMessage"])
 
     return response
 
@@ -37,10 +40,7 @@ def verify_otp(otp_id: str, otp_code: str, phone_number: str) -> Response:
     )
 
     if not response.ok:
-        raise Exception(
-            _(
-                f"Unable to validate your verification code. Please contact customer support."
-            )
-        )
+        json = response.json()
+        raise CommunicationApiException(json["errorMessage"])
 
     return response
