@@ -16,9 +16,14 @@ def _extract_message_from_detail(detail: Any) -> str:
         # This is so we can keep the "message" returned in the error as a whole string.
         return errors[0]
     elif isinstance(detail, dict):
-        errors = [f"{k}: {_extract_message_from_detail(v)}" for k, v in detail.items()]
         # Return the first error. Subsequent errors will be shown once the user fixes the first one.
         # This is so we can keep the "message" returned in the error as a whole string.
+        for key, value in detail.items():
+            if str(key).strip().lower() == "non_field_errors":
+                return _extract_message_from_detail(value)
+
+            return f"{key}: {_extract_message_from_detail(value)}"
+
         return errors[0]
     else:
         return str(detail)
